"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var web3_1 = __importDefault(require("web3"));
var constants_1 = require("../constants");
var constructMerkleLeaf = function (leaves) {
    if (leaves.length === 0) {
        return { height: 0, hash: constants_1.EMPTY_HASH };
    }
    else if (leaves.length === 1) {
        return { height: 0, hash: leaves[0].hash };
    }
    var left = leaves.slice(0, leaves.length / 2);
    var right = leaves.slice(leaves.length / 2, leaves.length);
    var leftChild = exports.constructMerkleTree(left);
    var rightChild = exports.constructMerkleTree(right);
    var height = leftChild.height + 1;
    var hash = web3_1.default.utils.soliditySha3({ t: 'uint32', v: leftChild.height }, { t: 'bytes32', v: leftChild.hash }, { t: 'bytes32', v: rightChild.hash });
    var result = { leftChild: leftChild, rightChild: rightChild, height: height, hash: hash };
    leftChild.parent = result;
    rightChild.parent = result;
    return result;
};
exports.constructMerkleTree = function (leaves) {
    if (leaves.length > 2) {
        var paddedLength = 2;
        while (paddedLength < leaves.length)
            paddedLength *= 2;
        while (leaves.length < paddedLength)
            leaves.push({ height: 0, hash: constants_1.EMPTY_HASH });
    }
    return constructMerkleLeaf(leaves);
};
exports.EMPTY_MERKLE_TREE = exports.constructMerkleTree([]);
//# sourceMappingURL=merkleTree.js.map