import { BigNumber } from 'bignumber.js';
import { WalletId, Wallet } from './index';
import { ActiveState } from './activeState';
import { MerkleTree } from './merkleTree';
export interface Transaction {
    id: number;
    txId: string;
    amount: BigNumber;
    amountSwapped: BigNumber;
    sender: WalletId;
    recipient: WalletId;
    nonce: BigNumber;
    passiveMarker: BigNumber;
    eon: number;
    time: number;
    senderActiveState: ActiveState;
    recipientActiveState?: ActiveState;
    senderCancellationActiveState?: ActiveState;
    recipientCancellationActiveState?: ActiveState;
    senderFinalizationActiveState?: ActiveState;
    recipientFinalizationActiveState?: ActiveState;
    recipientFulfillmentActiveState?: ActiveState;
    swap: boolean;
    matchedAmounts?: MatchedAmounts;
    complete: boolean;
    voided: boolean;
    processed?: boolean;
    cancelled?: boolean;
    appended?: boolean;
}
export interface MatchedAmounts {
    in: BigNumber;
    out: BigNumber;
}
export declare type TransferHashConfig = {
    passiveMarker?: BigNumber;
    nonce: BigNumber;
    senderAddress: string;
    recipientAddress: string;
    amount: BigNumber;
    recipientTrailIdentifier: number;
    isOutgoing: boolean;
};
export declare type SwapHashConfig = {
    creditToken: string;
    debitToken: string;
    trailIdentifier: number;
    amount: BigNumber;
    amountSwapped: BigNumber;
    startingBalance: BigNumber;
    nonce: BigNumber;
};
export declare type SwapFreezeHashConfig = {
    creditToken: string;
    debitToken: string;
    nonce: BigNumber;
};
export declare function hashTransfer(config: TransferHashConfig): string;
export declare function hashSwap(config: SwapHashConfig): string;
export declare function hashSwapFreezing(config: SwapFreezeHashConfig): string;
export declare function getTransactionActiveState(transaction: Transaction, isOutgoing: boolean): ActiveState;
export declare function transactionToMerkleTree(transaction: Transaction, wallet: Wallet, lastTransaction?: Transaction): MerkleTree;
export declare function getSwapEonCount(swap: Transaction): Promise<number>;
